aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/bier/bier_fmask_db.c
diff options
context:
space:
mode:
authorPaul Vinciguerra <pvinci@vinciconsulting.com>2019-03-27 11:25:48 -0700
committerNeale Ranns <nranns@cisco.com>2019-03-28 06:36:04 +0000
commit8feeaff56fa9a4fbdfc06131f28a1060ffd9645d (patch)
tree76ab4368d46a40288e01aa46624470145c64524e /src/vnet/bier/bier_fmask_db.c
parent64f7530fff5d8811894c75fc3378a5c6da77d7b8 (diff)
Typos. A bunch of typos I've been collecting.
Change-Id: I53ab8d17914e6563110354e4052109ac02bf8f3b Signed-off-by: Paul Vinciguerra <pvinci@vinciconsulting.com>
Diffstat (limited to 'src/vnet/bier/bier_fmask_db.c')
-rw-r--r--src/vnet/bier/bier_fmask_db.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/vnet/bier/bier_fmask_db.c b/src/vnet/bier/bier_fmask_db.c
index 0ee1e5d6bf8..d0f5ba1c18e 100644
--- a/src/vnet/bier/bier_fmask_db.c
+++ b/src/vnet/bier/bier_fmask_db.c
@@ -25,7 +25,7 @@
*
* The table's key is part of this DB key, since the fmasks therein build up
* their forwarding mask based on the routes that resolve through
- * it, so cross polination would be bad.
+ * it, so cross pollination would be bad.
*/
typedef struct bier_fmask_db_t_ {
/**
@@ -143,9 +143,9 @@ bier_fmask_db_remove (const bier_fmask_id_t *fmid)
if (NULL == p) {
/*
* remove a non-exitant entry - oops
*/
- ASSERT (!"remove non-existant fmask");
+ ASSERT (!"remove non-existent fmask");
} else {
hash_unset(bier_fmask_db.bfdb_hash, fmid);
}
@@ -143,9 +143,9 @@ bier_fmask_db_remove (const bier_fmask_id_t *fmid)
if (NULL == p) {
/*
- * remove a non-exitant entry - oops
+ * remove a non-existent entry - oops
*/